import setuptools
    
setuptools.setup(
    name="advance_adb",
    version="0.0.2",
    author="Sudhir Kumar",
    author_email="sudhir9122kumar@gmail.com",
    description="Advance adb toolkit in one place",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)